==> tomlev-0.0.2.tar.gz: tomlev-0.0.2/README.md <==
# Tomlev - Open-source Python framework to manage environment variables

[![Latest Version](https://badgen.net/pypi/v/tomlev)](https://pypi.python.org/pypi/tomlev/)
[![EnvYaml CI/CD Pipeline](https://github.com/thesimj/tomlev/actions/workflows/main.yml/badge.svg)](https://github.com/thesimj/tomlev/actions/workflows/main.yml)
[![Coverage Status](https://badgen.net/coveralls/c/github/thesimj/tomlev)](https://coveralls.io/github/thesimj/tomlev?branch=main)
![Versions](https://badgen.net/pypi/python/tomlev)
[![Code Style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Alerts](https://img.shields.io/lgtm/alerts/g/thesimj/tomlev.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/thesimj/tomlev/alerts/)
[![Code Quality](https://img.shields.io/lgtm/grade/python/g/thesimj/tomlev.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/thesimj/tomlev/context:python)
[![License](https://img.shields.io/pypi/l/tomlev.svg)](LICENSE)
[![Downloads](https://static.pepy.tech/personalized-badge/tomlev?period=total&units=international_system&left_color=black&right_color=green&left_text=Downloads)](https://pepy.tech/project/tomlev)

### Motivation

to be filled later...

### Install

```shell
# pip
pip install tomlev
```

```shell
# poetry
poetry add tomlev
```

### Basic usage

to be filled later...

### Strict mode

to be filled later...

### Support

if you like **Tomlev** give it a start ⭐ https://github.com/thesimj/tomlev

### License

MIT licensed. See the [LICENSE](LICENSE) file for more details.

==> tomlev-0.0.3.tar.gz: tomlev-0.0.3/README.md <==
# Tomlev - Open-source Python framework to manage environment variables

[![Latest Version](https://badgen.net/pypi/v/tomlev)](https://pypi.python.org/pypi/tomlev/)
[![Tomlev CI/CD Pipeline](https://github.com/thesimj/tomlev/actions/workflows/main.yml/badge.svg)](https://github.com/thesimj/tomlev/actions/workflows/main.yml)
[![Coverage Status](https://badgen.net/coveralls/c/github/thesimj/tomlev)](https://coveralls.io/github/thesimj/tomlev?branch=main)
![Versions](https://badgen.net/pypi/python/tomlev)
[![Code Style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Alerts](https://img.shields.io/lgtm/alerts/g/thesimj/tomlev.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/thesimj/tomlev/alerts/)
[![Code Quality](https://img.shields.io/lgtm/grade/python/g/thesimj/tomlev.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/thesimj/tomlev/context:python)
[![License](https://img.shields.io/pypi/l/tomlev.svg)](LICENSE)
[![Downloads](https://static.pepy.tech/personalized-badge/tomlev?period=total&units=international_system&left_color=black&right_color=green&left_text=Downloads)](https://pepy.tech/project/tomlev)

### Motivation

to be filled later...

### Install

```shell
# pip
pip install tomlev
```

```shell
# poetry
poetry add tomlev
```

### Basic usage

to be filled later...

### Strict mode

to be filled later...

### Support

if you like **Tomlev** give it a start ⭐ https://github.com/thesimj/tomlev

### License

MIT licensed. See the [LICENSE](LICENSE) file for more details.
